﻿using System;
using System.IO;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Optimization;
using HeuristicLab.PluginInfrastructure;

namespace HeuristicLab.DynamicAssemblyTestApp {
  [Serializable]
  public class AppTest : ApplicationBase {

    public UniPath InputFilePath { get; set; } = null;
    public UniPath OutputPath { get; set; } = null;
    public override void Run(ICommandLineArgument[] args) {
      ContentManager.Initialize(new PersistenceContentManager());
      IStorableContent content = ContentManager.Load(InputFilePath.ToString());
      IExecutable exec = content as IExecutable;
      if (exec != null) {
        exec.Start();
        IOptimizer optimizer = exec as IOptimizer;
        if (optimizer != null) {
          Console.WriteLine("\nRESULT(S):");
          int i = 1;
          foreach (var run in optimizer.Runs) {
            Console.WriteLine($"{"-------------------------------- RUN",35} {$"{i++:D3}" + " --------------------------------",-35}");
            foreach (var res in run.Results) {
              Console.WriteLine($"{res.Key,35} : {res.Value,-35}");
            }
          }
        }
        
        ContentManager.Save((IStorableContent)exec, OutputPath.ToString() + Path.DirectorySeparatorChar + "result.hl", true);
      } else throw new NotSupportedException("The given file does not contain any algorithm to start.");
    }
  }
}
